pub struct ClientResponse {
pub status: Status,
pub headers: Headers,
pub body: Vec<u8>,
}Expand description
A response from an outbound request.
Fields
status: Statusheaders: Headersbody: Vec<u8>Implementations
Sourceimpl ClientResponse
impl ClientResponse
pub fn text(&self) -> String
pub fn json(&self) -> Result<Json>
pub fn is_success(&self) -> bool
Sourcepub fn error_for_status(self) -> Result<ClientResponse>
pub fn error_for_status(self) -> Result<ClientResponse>
Turn a non-2xx response into an error, keeping the body — an API’s error message is usually the only thing that explains the failure.